Value class
Constructors
-
Value(num data, [Set<
Value> children = const {}, ValueOperation? operation])
Properties
-
children
→ Set<
Value> -
final
- data ↔ num
-
getter/setter pair
- grad ↔ num
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- label ↔ String?
-
getter/setter pair
- localBackward ↔ void Function()?
-
getter/setter pair
- operation → ValueOperation?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
backward(
) → void -
exponent(
) → Value -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
power(
Object exponent) → Value -
sigmoid(
) → Value -
tanh(
) → Value -
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator *(
Object other) → dynamic -
operator +(
Object other) → dynamic -
operator -(
Object other) → dynamic -
operator /(
Object other) → dynamic -
operator ==(
Object other) → bool -
The equality operator.
inherited