MultiLayerPerceptron class
Constructors
-
MultiLayerPerceptron({required int neuronInputsCount, required Iterable<
int> layerNeuronCounts})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
layerNeuronCounts
→ Iterable<
int> -
final
-
layers
→ Iterable<
Layer> -
final
- neuronInputsCount → int
-
final
-
parameters
→ List<
Value> -
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
forward(
Iterable< Object> inputs) → Iterable<Value> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
zeroGrad(
) → void -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited