Neuron class
Properties
- bias → Value
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputsCount → int
-
final
-
parameters
→ List<
Value> -
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
weights
→ Iterable<
Value> -
final
Methods
-
forward(
Iterable< Value> inputs) → Value -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
zeroGrad(
) → void -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited